h_east <[email protected]> wrote:

> Hi Bram and all,
>
> Thanks for the making patch 8.0.1016 and 8.0.1021
> The issue of GNOME terminal has been resolved.
>
> I am happy if you can add Judgment of PuTTY as well.
> (PuTTY 0.70 sends ">0;136;0c")
>
> I attach a patch to this email.


Latest vim (8.0.1026) still outputs spurious characters
with xfce4-terminal on xubuntu-16.04 (xfce4-terminal 0.6.3).
I see this when starting vim:

 [?12$p

Attached patch fixes it.

Regards
Dominique

-- 
-- 
You received this message from the "vim_dev" maillist.
Do not top-post! Type your reply below the text you are replying to.
For more information, visit http://www.vim.org/maillist.php

--- 
You received this message because you are subscribed to the Google Groups 
"vim_dev" group.
To unsubscribe from this group and stop receiving emails from it, send an email 
to [email protected].
For more options, visit https://groups.google.com/d/optout.
diff --git a/src/term.c b/src/term.c
index 4244892..8ec799e 100644
--- a/src/term.c
+++ b/src/term.c
@@ -4562,10 +4562,11 @@ check_termcode(
 				&& STRNCMP(tp + extra - 2, "1;95;0c", 7) == 0)
 			    is_not_xterm = TRUE;
 #  endif
 			/* Gnome Terminal.app sends 1;3801;0 or 1;4402;0,
 			 * assuming any version number over 3000 is not an
 			 * xterm. */
-			if (col >= 3000)
+			if (col >= 2800)
 			    is_not_xterm = TRUE;
 
 			/* Only request the cursor style if t_SH and t_RS are
@@ -4562,10 +4562,11 @@ check_termcode(
 			    is_not_xterm = TRUE;
 #  endif
-			/* Gnome Terminal.app sends 1;3801;0 or 1;4402;0,
-			 * assuming any version number over 3000 is not an
+			/* Gnome Terminal.app sends 1;3801;0 or 1;4402;0.
+			 * xfce4-terminal sends 1;2802;0.
+			 * Assuming any version number over 2800 is not an
 			 * xterm. */

Raspunde prin e-mail lui